@@ -28,6 +28,9 @@ def arg_parse(config_file):
     version_name = args.version
     upload_file_path = args.source
 
+    with open(config_file) as yaml_file:
+        config_file = yaml.load(yaml_file)
+
     if args.check:
         parse_config(config_file)
         exit(0)
