@@ -7,7 +7,7 @@ def check_upload_file(upload_file):
         for root, dirs, files in os.walk(upload_file):
             for file in files:
                 if file == "Packages.gz" or file == "Packages":
-                    print("Packages file found: " + file + "assuming this is a valid folder for upload")
+                    print("Packages file found: " + file + " ,assuming this is a valid folder for upload")
                     return True
                 else:
                     print("Packages file not found: " + file)
